#This controls de admin forms to manipulate the database.
#The plan is to let administrator control inventoru and all other important site functions from here.

from django.contrib import admin
from erp.models import Imagemestoque, Ordem, Loja #Need to import from the app root as it can't refernce back
from erp.assets.adminactions import importa_jogos, retorno_pedidos, entrega_pedidos, paga_pedidos, finaliza_pedidos

#Form para gerenciar produtos (incluindo imagens) pelo admin
#===========================================================

class ImagemestoqueInline(admin.TabularInline):
    model = Imagemestoque
    extra = 3
    
class EstoqueAdmin(admin.ModelAdmin):
    list_display = ["nome","nomeludopedia", "valor","quantidade","disponivel"]
    list_filter = ["dtatualizacao", "disponivel"] #Not sure if we will keep it here
    search_fields = ["nome", "nomeludopedia"]
    fieldsets = [
        (None, {"fields": ["nome", "descricao"]}),
        ("Dados Comerciais", {"fields": ["valor", "quantidade", "disponivel"]}),
        ("Dados  Adicionais do Jogo", { "classes": ["collapse"],
                            "fields": ["nomeludopedia", "tempodejogo", "minjogadores", "maxjogadores","idade", "tags"]}),
        #("Tags", {"fields": ["tags"]})
        ]
    inlines = [ImagemestoqueInline]
    actions = [importa_jogos]
    filter_horizontal = ["tags"]
    


#Form para gerenciar pedidos pelo admin
#======================================
class OrdemInline(admin.TabularInline):
    model = Ordem
    extra = 3
    
class PedidoAdmin(admin.ModelAdmin):
    list_display = ["pk", "cliente", "dtpedido", "dtatualizacao", "status", "valortotal"]
    list_filter = ["dtatualizacao", "status", "cliente"]
    fieldsets = [
        (None, {"fields": ["cliente", "status", "dataenvio", "dataretorno"]}),
        ("Detalhes do Pedido", {"classes":["collapse"],
                                "fields": [("valorproduto", "valorfrete", "valortotal", "formapagamento"), ("dtpedido", "dtatualizacao")]}), 
        ("Detalhas da Entrega", {"classes": ["collapse"], 
                                "fields": ["tipoentrega", "endereco","complemento", "cep", "bairro", "cidade", "estado", "notas"],
                                "fields": [("dtpago", "dtentregue", "dtfim")] }),
        #debugging fields
        #("Controle - Remove from Prod", {"fields": [("controlpago","dtpago"),("controlentregue","dtentregue"),("controlencerrado","dtfim")]}),
        ]
    readonly_fields = ["valorproduto", "valorfrete","valortotal", "dtpedido", "dtatualizacao"]
    #search_fields = ["cliente_id.profile.nome"] #Need to figura out how to navigate into the user info to make it more readable here
    inlines = [OrdemInline]
    actions = [paga_pedidos, entrega_pedidos, retorno_pedidos, finaliza_pedidos]
    
        

#Add filters to Cart data. Better for admin    
class CartAdmin(admin.ModelAdmin):
    list_display = ["user", "product", "quantity"]
    list_filter = ["user"]
    search_fields = ["product__nome", "user__username"]
    

#Form for User profile (Apenas para agrupar coisas de modo mais organizado)
class ProfileAdmin(admin.ModelAdmin):
    list_display = ["user", "nome", "get_email", "dtcadastro"]
    list_filter = ["dtatualizacao", "bairro", "cidade"]
    search_fields = ["nome", "user__username"]
    fieldsets = [
            (None, {"fields": ["user", "get_email", "nome", "asaasid", "phone", "cpf"]
            }),
            ("Endereço", {#"classes":["collapse", "start-open"],
                        "fields": [("endereco", "complemento"), ("bairro", "cidade", "estado"), "cep"]
            }), 
            ("Detalhas Pessoais", {"classes": ["collapse"], 
                                    "fields": ["dtnascimento", "foto", "fotorg", "fotocpf", "fotocomprovante"],
            }),
    ]
    readonly_fields = ["user", "get_email"]


#Add filters to Cart data. Better for admin    
class FAQAdmin(admin.ModelAdmin):
    list_display = ["pergunta"]
    search_fields = ["pergunta"]


#Add filters to Cart data. Better for admin    
class FreteAdmin(admin.ModelAdmin):
    #list_display = [""]
    search_fields = ["estado", "cidade", "bairro"]
    
class LojaAdmin(admin.ModelAdmin):
    #This allows a single record for the store
    def has_add_permission(self, request): # Here
        return not Loja.objects.exists()
    #Normal stuff
    fieldsets = [
            (None, {"fields": ["cnpj", "nome", "logo", ("email","notificapedido"), "intro"]
            }),
            ("Chaves de Pagamento", {"classes":["collapse"],
                                    "fields": ["asaastoken", "asaaswebhook"]
            }),
            ("Imagens do Site para Clientes", {"classes": ["collapse"], 
                                    "fields": ["imageminicio", "imagemaluga", "imagemfaq"],
            }),
            ("Endereço da Loja", {"classes": ["collapse"], 
                                    "fields": [("endereco", "complemento"), ("bairro", "cidade", "estado", "cep")],
            }),
            ("Midias Sociais", {"classes": ["collapse"], 
                                    "fields": ["googleanalytics", "instagram", "x", "whatsapp","telegram", "facebook", "tiktok", "youtube"],
            }),
    ]
    
#Form for Payments profile (Apenas para agrupar coisas de modo mais organizado)
class PagamentoAdmin(admin.ModelAdmin):
    list_display = ["get_pedido", "cliente", "paymentID", "status", "valorcobranca", "tarifa"]
    list_filter = ["dtsubmetido"]
    search_fields = ["pedido__pk", "cliente__username"]
    fieldsets = [
            (None, {"fields": ["pedido", "paymentID", ("valorcobranca", "tarifa", "dtsubmetido"), ("billingtype", "status")]
            }),
            ("Info Asaas", {"classes":["collapse", "start-open"],
                        "fields": ["invoiceurl", "transactionreceipturl", "remoteip", "retornobancario"]
            }), 
    ]
    readonly_fields = ["pedido", "get_pedido", "cliente", 'dtsubmetido', 'tarifa', "status", "billingtype", "valorcobranca", "paymentID", "invoiceurl", "transactionreceipturl", "remoteip", "retornobancario"]
